==> haskell-profunctors-5.3-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.3
id: profunctors-5.3-AUW0bCu5vnKgpmUhJ4x00
key: profunctors-5.3-AUW0bCu5vnKgpmUhJ4x00
license: BSD-3-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors.
category: Control, Categories
abi: c49af9bb35e0c06da2b66b52857d400e
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda
import-dirs: /usr/lib/ghc-8.6.1/site-local/profunctors-5.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/profunctors-5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/profunctors-5.3
hs-libraries: HSprofunctors-5.3-AUW0bCu5vnKgpmUhJ4x00
depends:
    base-4.12.0.0 base-orphans-0.8-8rWfFkGLAVR6Lt3dCtqcr
    bifunctors-5.5.3-2Koe0TeKgTk6hFvOjxEoX
    comonad-5.0.4-Gg2EZ4OBRR53rLr1UGRkQ3
    contravariant-1.5-4tjvhiNPMk29NhGPKE1GIF
    distributive-0.6-KhtRTRkgO5N2zygz7Ugp5t
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.3-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.3
id: profunctors-5.3-3ZUOvQmFZbaJi6Rfb5qOvJ
key: profunctors-5.3-3ZUOvQmFZbaJi6Rfb5qOvJ
license: BSD-3-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors.
category: Control, Categories
abi: b59979cea4f54e20e1d3d6fd8417576c
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda
import-dirs: /usr/lib/ghc-8.6.2/site-local/profunctors-5.3
library-dirs: /usr/lib/ghc-8.6.2/site-local/profunctors-5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/profunctors-5.3
hs-libraries: HSprofunctors-5.3-3ZUOvQmFZbaJi6Rfb5qOvJ
depends:
    base-4.12.0.0 base-orphans-0.8-I5Wy5X7j4JPBlGRIrsmaA5
    bifunctors-5.5.3-hvHUZecmY8K0Xh4IDTpkC
    comonad-5.0.4-LBTE5MzQHFTCR2pjCvdKVj
    contravariant-1.5-4tjvhiNPMk29NhGPKE1GIF
    distributive-0.6-DXoAeTRQfx24bGl75foabZ
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
